@@ -1,5 +1,7 @@
+// Avoid 3 sec timeout ?
+Streamlit.setComponentReady();
 (function() {
-  
+
     function sendValue(value) {
       Streamlit.setComponentValue(value)
     }
@@ -95,11 +97,14 @@
                   observer.disconnect();
               }
           });
-
-          observer.observe(document.body, {
+          try {
+              observer.observe(document.body, {
               childList: true,
               subtree: true
           });
+          } catch (error) {
+            
+          }
       });
     }
 
@@ -155,5 +160,5 @@
     }
 
     Streamlit.events.addEventListener(Streamlit.RENDER_EVENT, onRender);
-    Streamlit.setComponentReady();
 })();
+
